# uname コマンド

オペレーティングシステムに関するシステム情報を表示します。

## 概要

`uname` コマンドは、コンピュータで実行されているオペレーティングシステムに関するシステム情報を表示します。カーネル名、ネットワークノードのホスト名、カーネルリリース、カーネルバージョン、マシンのハードウェア名、プロセッサタイプ、ハードウェアプラットフォーム、およびオペレーティングシステムを表示できます。

## オプション

### **-a, --all**

以下の順序ですべての情報を表示します：カーネル名、ネットワークノードのホスト名、カーネルリリース、カーネルバージョン、マシンのハードウェア名、プロセッサタイプ、ハードウェアプラットフォーム、オペレーティングシステム。

```console
$ uname -a
Linux hostname 5.15.0-76-generic #83-Ubuntu SMP Thu Jun 15 19:16:32 UTC 2023 x86_64 x86_64 GNU/Linux
```

### **-s, --kernel-name**

カーネル名を表示します。オプションが指定されていない場合のデフォルトです。

```console
$ uname -s
Linux
```

### **-n, --nodename**

ネットワークノードのホスト名を表示します。

```console
$ uname -n
hostname
```

### **-r, --kernel-release**

カーネルリリースを表示します。

```console
$ uname -r
5.15.0-76-generic
```

### **-v, --kernel-version**

カーネルバージョンを表示します。

```console
$ uname -v
#83-Ubuntu SMP Thu Jun 15 19:16:32 UTC 2023
```

### **-m, --machine**

マシンのハードウェア名を表示します。

```console
$ uname -m
x86_64
```

### **-p, --processor**

プロセッサタイプを表示します（不明な場合は「unknown」と表示されます）。

```console
$ uname -p
x86_64
```

### **-i, --hardware-platform**

ハードウェアプラットフォームを表示します（不明な場合は「unknown」と表示されます）。

```console
$ uname -i
x86_64
```

### **-o, --operating-system**

オペレーティングシステムを表示します。

```console
$ uname -o
GNU/Linux
```

## 使用例

### カーネル情報の取得

```console
$ uname -sr
Linux 5.15.0-76-generic
```

### 互換性のためのアーキテクチャの確認

```console
$ uname -m
x86_64
```

### システム情報の完全表示

```console
$ uname -a
Linux hostname 5.15.0-76-generic #83-Ubuntu SMP Thu Jun 15 19:16:32 UTC 2023 x86_64 x86_64 GNU/Linux
```

## ヒント:

### システムアーキテクチャの識別

`uname -m` を使用して、システムが32ビット（i686）か64ビット（x86_64）かを素早く識別できます。これはソフトウェアをダウンロードしたり、ソースからコンパイルしたりする際に重要です。

### カーネルバージョンの確認

カーネル依存のソフトウェアやドライバをインストールする前に、`uname -r` を使用してカーネルバージョンを確認します。

### オプションの組み合わせ

`uname -sr` のように複数のオプションを組み合わせて、すべてを表示せずに特定の情報を取得できます。

## よくある質問

#### Q1. システムが32ビットか64ビットかを確認するにはどうすればよいですか？
A. `uname -m` を使用します。「x86_64」が返される場合は64ビットシステム、「i686」または「i386」が返される場合は32ビットシステムです。

#### Q2. Linuxカーネルバージョンを確認するにはどうすればよいですか？
A. `uname -r` を使用してカーネルリリースバージョンを表示します。

#### Q3. `uname -v` と `uname -r` の違いは何ですか？
A. `uname -r` はカーネルリリース（「5.15.0-76-generic」など）を表示し、`uname -v` はビルド情報を含むカーネルバージョン（「#83-Ubuntu SMP Thu Jun 15 19:16:32 UTC 2023」など）を表示します。

#### Q4. 使用しているLinuxディストリビューションを確認するにはどうすればよいですか？
A. `uname` はカーネル情報のみを表示します。ディストリビューションを確認するには、代わりに `cat /etc/os-release` または `lsb_release -a` を使用します。

## macOSに関する考慮事項

macOSでは、`uname` は同様に機能しますが、いくつかの違いがあります：
- `-o` オプションはmacOSでは利用できません
- `uname -a` の出力では、カーネル名として「Linux」ではなく「Darwin」が表示されます
- macOSのバージョン情報を取得するには、代わりに `sw_vers` を使用します

## 参考文献

https://www.gnu.org/software/coreutils/manual/html_node/uname-invocation.html

## 改訂履歴

- 2025/05/05 初版